@@ -1,6 +1,4 @@
-import os
 from django.core.files.storage import Storage
-from django.conf import settings
 from celery import task
 from .signals import transaction_signals
 
@@ -25,6 +23,15 @@ class DelayHook(Storage):
     def delete_instantly(self, name):
         return self.storage.delete(name)
 
+    def rename(self, old_file, new_filename, rewrite=False):
+        old_filename = old_file.name
+        if rewrite:
+            self.delete_instantly(new_filename)
+        else:
+            new_filename = self.storage.get_available_name(new_filename)
+        old_file.save(new_filename, old_file)
+        self.storage.delete(old_filename)
+
     def _save(self, name, content):
         self.delete_on_rollback.append(name)
         return self.storage.save(name, content)
